/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.util.activator.impl;

import static com.openexchange.util.custom.base.NullUtil.absent;
import java.lang.annotation.Annotation;
import java.lang.reflect.Constructor;
import java.lang.reflect.Method;


import com.google.common.base.Optional;
import com.openexchange.annotation.Nullable;
import com.openexchange.util.activator.ServiceDependencyResolver;
import com.openexchange.util.activator.ServiceRef;


/**
 * {@link EmptyServiceDependencyResolver}
 *
 * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
 * @since v1.0.2
 */
public enum EmptyServiceDependencyResolver implements ServiceDependencyResolver {
    INSTANCE;

    @Override
    public Optional<Object[]> resolveParameters(Constructor<?> constructor) {
        return absent();
    }

    @Override
    public Optional<Object[]> resolveParameters(Method method) {
        return absent();
    }

    @Override
    public @Nullable <X> X resolveMandatoryService(Class<X> serviceClass, @Nullable Annotation[] annotations) {
        return null;
    }

    @Override
    public @Nullable <X> ServiceRef<X> resolveOptionalService(Class<X> serviceClass, @Nullable Annotation[] annotations) {
        return null;
    }

}
