/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.util.custom.base;

import static com.openexchange.util.custom.base.NullUtil.f;


@SuppressWarnings("serial")
public final class FailedInterpolationException extends RuntimeException {
    private final String unresolvedPlaceholder;
    public FailedInterpolationException(final String unresolvedPlaceholder) {
        super(f("could not resolve placeholder ${%s}", unresolvedPlaceholder));
        this.unresolvedPlaceholder = unresolvedPlaceholder;
    }
    public FailedInterpolationException(final String unresolvedPlaceholder, final Throwable cause) {
        super(f("could not resolve placeholder ${%s}", unresolvedPlaceholder), cause);
        this.unresolvedPlaceholder = unresolvedPlaceholder;
    }
    public FailedInterpolationException(final String unresolvedPlaceholder, final String reason) {
        super(f("could not resolve placeholder ${%s}: %s", unresolvedPlaceholder, reason));
        this.unresolvedPlaceholder = unresolvedPlaceholder;
    }
    public String unresolvedPlaceholder() {
        return unresolvedPlaceholder;
    }
}
